/* vi: set sw=4 ts=4: */
/*
 * lunar-calendar-version.h: This file is part of lunar-calendar.
 *
 * Copyright (C) 2009-2022 yetist <yetist@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, see <http://www.gnu.org/licenses/>.
 * */

#ifndef __LUNAR_CALENDAR_VERSION_H__
#define __LUNAR_CALENDAR_VERSION_H__  1

#include <glib.h>

G_BEGIN_DECLS

/**
 * LUNAR_CALENDAR_MAJOR_VERSION:
 *
 * The major version number of the LunarCalendar library
 * (e.g. in version 2.4.0 this is 2).
 *
 * Since: 2.4.0
 */
#define LUNAR_CALENDAR_MAJOR_VERSION	3

/**
 * LUNAR_CALENDAR_MINOR_VERSION:
 *
 * The minor version number of the LunarCalendar library
 * (e.g. in version 2.4.0 this is 4).
 *
 * Since: 2.4.0
 */
#define LUNAR_CALENDAR_MINOR_VERSION	0

/**
 * LUNAR_CALENDAR_MICRO_VERSION:
 *
 * The macro version number of the LunarCalendar library
 * (e.g. in version 2.4.0 this is 0).
 *
 * Since: 2.4.0
 */
#define LUNAR_CALENDAR_MICRO_VERSION	1

/**
 * lunar_calendar_major_version:
 *
 * The major version number of the LunarCalendar library
 * (e.g. in version 2.4.0 this is 2). Used for runtime.
 *
 * Since: 2.4.0
 */
extern const guint lunar_calendar_major_version;

/**
 * lunar_calendar_minor_version:
 *
 * The minor version number of the LunarCalendar library
 * (e.g. in version 2.4.0 this is 4). Used for runtime.
 *
 * Since: 2.4.0
 */
extern const guint lunar_calendar_minor_version;

/**
 * lunar_calendar_micro_version:
 *
 * The micro version number of the LunarCalendar library
 * (e.g. in version 2.4.0 this is 0). Used for runtime.
 *
 * Since: 2.4.0
 */
extern const guint lunar_calendar_micro_version;

const gchar * lunar_calendar_check_version (guint required_major,
                                            guint required_minor,
                                            guint required_micro);

/**
 * LUNAR_CALENDAR_CHECK_VERSION:
 * @major: required major version
 * @minor: required minor version
 * @micro: required micro version
 *
 * Checks the version of the LunarCalendar library.
 *
 * Checking the version of the LunarCalendar library:
 * |[
 *   if (!LUNAR_CALENDAR_CHECK_VERSION (2, 4, 0))
 *       g_error ("LunarCalendar version 2.4.0 or above is needed");
 * ]|
 *
 * Returns: %TRUE if the version of the LunarCalendar header files is the same
 * as or newer than the passed-in version.
 *
 * Since: 2.4.0
 */
#define LUNAR_CALENDAR_CHECK_VERSION(major,minor,micro)    \
	(LUNAR_MAJOR_VERSION > (major) || \
	 (LUNAR_MAJOR_VERSION == (major) && LUNAR_MINOR_VERSION > (minor)) || \
	 (LUNAR_MAJOR_VERSION == (major) && LUNAR_MINOR_VERSION == (minor) && \
	  LUNAR_MICRO_VERSION >= (micro)))


G_END_DECLS

#endif /* __LUNAR_CALENDAR_VERSION_H__ */

/*
vi:ts=4:wrap:ai:
*/
